mod indicators {
    pub mod error;
    pub mod git;
    pub mod pwd;
    pub mod ssh;
    pub mod user;
}

use crate::indicators::error;
use crate::indicators::git;
use crate::indicators::pwd;
use crate::indicators::ssh;
use crate::indicators::user;

fn main() {
    let cmd_args: Vec<String> = std::env::args().collect();

    let mut components: Vec<String> = Vec::new();

    let indicate_user: bool = true;
    let indicate_ssh: bool = true;
    let indicate_err: bool = true;
    let indicate_git_branch: bool = true;
    let show_pwd: bool = true;
    let abbrev_home: bool = true;
    let shorten_path: bool = true;
    let replace_repo: bool = true;
    let mut git_info = None;

    if indicate_ssh {
        components.push(ssh::indicator().to_string());
    }
    if indicate_git_branch {
        git_info = git::info();
        match git_info {
            Some(ref info) => components.push(git::indicator(Some(info.1.clone())).to_string()),
            None => components.push(git::indicator(None).to_string()),
        }
    }
    if indicate_user {
        components.push(user::indicator().to_string());
    }
    if indicate_err {
        components.push(error::indicator(cmd_args).to_string());
    }
    if show_pwd {
        let repo_path = match git_info {
            Some(info) => Some(info.0), // Clone to avoid ownership issues
            None => None,
        };
        components.insert(
            0,
            pwd::pwd(abbrev_home, shorten_path, replace_repo, repo_path).to_string(),
        );
    }
    let prompt = components.join("");
    print!("{prompt} ");
}
